Crate aptos_testcontainer
source ·Expand description
Overview
This module provides a simple and smart test container framework for testing interactions with an Aptos node. The framework is designed to easily initialize and manage a containerized Aptos environment, making it straightforward to write integration tests for Aptos-based applications.
Modules
- Responsible for handling the logic of an Aptos container.
- Defines error types and custom error handling related to the Aptos container operations.
- Provides utilities and helper functions for testing the Aptos container.
- A helper function used across the test container.